@@ -1,12 +1,13 @@
 ### FUNCTION TO DRAW SPECIAL CASE 130 #############################################################
 draw.130 <- function(a1, a2, a3, a4, a5, a6, a7, category = rep("", 3), reverse = FALSE, cat.default.pos = "outer", lwd = rep(2, 3), lty = rep("solid", 3), col = rep("black", 3), label.col = rep("black", 7), cex = rep(1, 7), fontface = rep("plain", 7), fontfamily = rep("serif", 7), cat.pos = c(-40, 40, 180), cat.dist = c(0.05, 0.05, 0.025), cat.col = rep("black", 3), cat.cex = rep(1, 3), cat.fontface = rep("plain", 3), cat.fontfamily = rep("serif", 3), cat.just = list(c(0.5, 1), c(0.5, 1), c(0.5, 0)), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 3), scaled = TRUE, sep.dist = rep(0.05, 3), ...) {
-	if (length(sep.dist) == 1) { sep.dist <- rep(sep.dist, 3) }
-	i <- 1;
-	while (i <= 3) {
+
+	if (1 == length(sep.dist) ) { sep.dist <- rep(sep.dist, 3); }
+
+	for (i in 1:3) {
 		tmp <- VennDiagram::rotate.sp(c(a1, a2, a3, a4, a5, a6, a7), category, i, reverse);
-		if (tmp[[1]][2] == 0 & tmp[[1]][4] == 0 & tmp[[1]][5] == 0 & tmp[[1]][6] == 0) {i <- 4}
-		else {i <- i + 1}
+		if (0 == tmp[[1]][2] & 0 == tmp[[1]][4] & 0 == tmp[[1]][5] & 0 == tmp[[1]][6]) { break; }
 		}
+
 	a1 <- tmp[[1]][1];
 	a3 <- tmp[[1]][3];
 	a7 <- tmp[[1]][7];
@@ -21,8 +22,7 @@ draw.130 <- function(a1, a2, a3, a4, a5, a6, a7, category = rep("", 3), reverse
 		r2 <- r2 * shrink.factor;
 		r3 <- r3 * shrink.factor;
 		}
-		
-	if (!scaled) {
+	else {
 		r1 <- 0.18;
 		r2 <- 0.18;
 		r3 <- 0.18;
@@ -79,6 +79,6 @@ draw.130 <- function(a1, a2, a3, a4, a5, a6, a7, category = rep("", 3), reverse
 			fill = fill, 
 			alpha = alpha,
 			...
-		)
-	)
-}
+			)
+		);
+	}
