@@ -1,10 +1,12 @@
 ### FUNCTION TO DRAW VENN DIAGRAM WITH TWO SETS ###################################################
-draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2), euler.d = TRUE, scaled = TRUE, inverted = FALSE, ext.text = TRUE, lwd = rep(2, 2), lty = rep("solid", 2), col = rep("black", 2), fill = NULL, alpha = rep(0.5, 2), label.col = rep("black", 3), cex = rep(1, 3), fontface = rep("plain", 3), fontfamily = rep("serif", 3), cat.pos = c(-50, 50), cat.dist = rep(0.025, 2), cat.cex = rep(1, 2), cat.col = rep("black", 2), cat.fontface = rep("plain", 2), cat.fontfamily = rep("serif", 2), cat.just = rep(list(c(0.5, 0.5)), 2), cat.default.pos = "outer", cat.prompts = FALSE, ext.pos = rep(0, 2), ext.dist = rep(0, 2), ext.line.lty = "solid", ext.length = rep(0.95, 2), ext.line.lwd = 1, rotation.degree = 0, rotation.centre = c(0.5, 0.5), ind = TRUE, sep.dist = 0.05, offset = 0, ...) {
+draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2), euler.d = TRUE, scaled = TRUE, inverted = FALSE, ext.text = TRUE, ext.percent = rep(0.05, 3), lwd = rep(2, 2), lty = rep("solid", 2), col = rep("black", 2), fill = NULL, alpha = rep(0.5, 2), label.col = rep("black", 3), cex = rep(1, 3), fontface = rep("plain", 3), fontfamily = rep("serif", 3), cat.pos = c(-50, 50), cat.dist = rep(0.025, 2), cat.cex = rep(1, 2), cat.col = rep("black", 2), cat.fontface = rep("plain", 2), cat.fontfamily = rep("serif", 2), cat.just = rep(list(c(0.5, 0.5)), 2), cat.default.pos = "outer", cat.prompts = FALSE, ext.pos = rep(0, 2), ext.dist = rep(0, 2), ext.line.lty = "solid", ext.length = rep(0.95, 2), ext.line.lwd = 1, rotation.degree = 0, rotation.centre = c(0.5, 0.5), ind = TRUE, sep.dist = 0.05, offset = 0, ...) {
 
 	# area1 > area2 OR area1 < area2 plots the same Venn diagram.  Invert using the "inverted" argument.
 	# check parameter lengths and plausibility of Venn diagram
 	if (length(category) == 1) {category <- rep(category, 2)}
 	if (length(category) != 1 & length(category) != 2) { stop("Unexpected parameter length for 'category'") }
+	if (length(ext.percent) == 1) {ext.percent <- rep(ext.percent, 3)}
+	if (length(ext.percent) != 3) { stop("Unexpected parameter length for 'ext.percent'") }
 	if (length(ext.pos) == 1) {ext.pos <- rep(ext.pos, 2)}
 	if (length(ext.pos) != 1 & length(ext.pos) != 2) { stop("Unexpected parameter length for 'ext.pos'") }
 	if (length(ext.dist) == 1) {ext.dist <- rep(ext.dist, 2)}
@@ -46,7 +48,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 	if (!(class(cat.just) == "list" & length(cat.just) == 2 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2)) { stop("Unexpected parameter format for 'cat.just'") }
 	
 	# check uninterpretable parameters
-	if (euler.d == FALSE & scaled == TRUE) {
+	if (!euler.d & scaled) {
 		stop("Uninterpretable parameter combination\nPlease set both euler.d = FALSE and scaled = FALSE to force Venn diagrams.");
 		}
 	if (offset > 1 | offset < 0) {
@@ -57,30 +59,32 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 	cat.pos <- cat.pos + rotation.degree;
 	
 	# check category label defaults
-	if (((cat.default.pos != "outer") & (cat.default.pos != "text")) & cat.prompts) { # PHH: removed this check from the if, so that code works with expressions: & isTRUE(category != rep("", 2))
+	if (((cat.default.pos != 'outer') & (cat.default.pos != "text")) & cat.prompts) { # PHH: removed this check from the if, so that code works with expressions: & isTRUE(category != rep("", 2))
 		print("No default location recognized.  Automatically changing to 'outer'");
-		cat.default.pos <- "outer"
+		cat.default.pos <- 'outer';
 		}
-	if ((cat.default.pos == "outer") & cat.prompts) {
+	if ((cat.default.pos == 'outer') & cat.prompts) {
 		print("Placing category labels at default outer locations.  Use 'cat.pos' and 'cat.dist' to modify location.");
 		print(paste("Current 'cat.pos':", cat.pos[1], "degrees,", cat.pos[2], "degrees"));
 		print(paste("Current 'cat.dist':", cat.dist[1], ",", cat.dist[2]));
 		}
-	if ((cat.default.pos == "text") & cat.prompts) {
+	if ((cat.default.pos == 'text') & cat.prompts) {
 		print("Placing category labels at default text locations.  Use 'cat.pos' and 'cat.dist' to modify location.");
 		print(paste("Current 'cat.pos':", cat.pos[1], "degrees,", cat.pos[2], "degrees"));
 		print(paste("Current 'cat.dist':", cat.dist[1], ",", cat.dist[2]));
 		}
 		
 	max.circle.size = 0.2;
+
 	# initialize logical variables to hold special conditions
 	special.coincidental <- FALSE;
 	special.inclusion <- FALSE;
 	special.exclusion <- FALSE;
+
 	# initialize gList to hold all Grobs generated
 	grob.list <- gList();
-	
-	if (inverted == FALSE) {
+
+	if (!inverted) {
 		tmp1 <- max(area1, area2);
 		tmp2 <- min(area1, area2);
 		area1 <- tmp1;
@@ -117,7 +121,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		fill <- rev(fill);
 		alpha <- rev(alpha);
 		}	
-		
+
 	# convert radii to Grid dimensions
 	r1 <- r1 * shrink.factor;
 	r2 <- r2 * shrink.factor;
@@ -125,15 +129,16 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 	# check special conditions
 	if (area1 == area2 & area2 == cross.area) { special.coincidental <- TRUE; }
 	if (cross.area == area2 | cross.area == area1) { special.inclusion <- TRUE; }
-	if (cross.area == 0) { special.exclusion <- TRUE; }
+	if (0 == cross.area) { special.exclusion <- TRUE; }
 
 	# plot scaled, generic pairwise Venn diagram with or without external texts
 	if (scaled & !special.inclusion & !special.exclusion & !special.coincidental) {
+
 		d <- find.dist(area1, area2, cross.area, inverted = inverted);
 		d <- d * shrink.factor;
 		x.centre.1 <- (1 + r1 - r2 - d) / 2;
 		x.centre.2 <- x.centre.1 + d;
-		
+
 		tmp <- circle(
 			x = x.centre.1, 
 			y = 0.5, 
@@ -166,7 +171,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[1],
 				lty = lty[1],
 				col = col[1],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -179,13 +184,13 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[2],
 				lty = lty[2],
 				col = col[2],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			); 
 		grob.list <- gList(grob.list, tmp);
 		
 		if (ext.text) {
-			if ( (area1 - cross.area) / area1 > 0.05 & (area1 - cross.area) / area2 > 0.05) { 
+			if ( (area1 - cross.area) / area1 > ext.percent[1] & (area1 - cross.area) / area2 > ext.percent[1]) { 
 				area.1.pos <- x.centre.1 - r1 + ( (2 * r1 - (r1 + r2 - d)) / 2);
 				tmp <- textGrob(
 					label = area1 - cross.area, 
@@ -228,7 +233,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				}
-			if ( (area2 - cross.area) / area2 > 0.05 & (area2 - cross.area) / area1 > 0.05) { 
+
+			if ( (area2 - cross.area) / area2 > ext.percent[2] & (area2 - cross.area) / area1 > ext.percent[2]) { 
 				area.2.pos <- x.centre.2 + r2 - ( (2 * r2 - (r1 + r2 - d)) / 2);
 				tmp <- textGrob(
 					label = area2 - cross.area, 
@@ -271,7 +277,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				}
-			if ( cross.area / area2 > 0.05 & cross.area / area1 > 0.05) { 
+
+			if ( cross.area / area2 > ext.percent[3] & cross.area / area1 > ext.percent[3]) { 
 				tmp <- textGrob(
 					label = cross.area, 
 					x = x.centre.1 + (d - r2) + (r1 + r2 - d) / 2, 
@@ -314,6 +321,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				grob.list <- gList(grob.list, tmp);
 				}
 			}
+
 		if (!ext.text) {
 			area.1.pos <-  x.centre.1 - r1 + ( (2 * r1 - (r1 + r2 - d)) / 2);
 			tmp <- textGrob(
@@ -356,11 +364,11 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			}	
 
 		# find the location of the category labels
-		if (cat.default.pos == "outer") {
+		if (cat.default.pos == 'outer') {
 			cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1);
 			cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2);
 			}
-		else if (cat.default.pos == "text") {
+		else if (cat.default.pos == 'text') {
 			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
@@ -395,9 +403,9 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-	
+
 		}
-	
+
 	# plot scaled Venn diagram when one set is completely included in (but not exactly coincidental with) the other set 
 	# with or without external texts
 	if (euler.d & special.inclusion & !special.coincidental) {
@@ -451,7 +459,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[1],
 				lty = lty[1],
 				col = col[1],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -464,7 +472,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[2],
 				lty = lty[2],
 				col = col[2],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -545,11 +553,11 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				}
 			}
 		
-		if (cat.default.pos == "outer") {
+		if (cat.default.pos == 'outer') {
 			cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], r1);
 			cat.pos.2 <- find.cat.pos(0.5 - offset * (r1 - r2), 0.5, cat.pos[2], cat.dist[2], r2);
 			}
-		else if (cat.default.pos == "text") {
+		else if (cat.default.pos == 'text') {
 			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
@@ -610,7 +618,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[1],
 				lty = lty[1], 
 				col = col[1],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -644,7 +652,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 
 		tmp <- textGrob(
-			label = "(Coincidental)", 
+			label = '(Coincidental)', 
 			x = 0.5, 
 			y = 0.45, 
 			gp = gpar(
@@ -740,7 +748,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[1],
 				lty = lty[1],
 				col = col[1],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -753,7 +761,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[2],
 				lty = lty[2], 
 				col = col[2],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -786,11 +794,11 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") {
+		if (cat.default.pos == 'outer') {
 			cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1);
 			cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2);
 			}
-		else if (cat.default.pos == "text") {
+		else if (cat.default.pos == 'text') {
 			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
@@ -863,7 +871,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[1],
 				lty = lty[1],
 				col = col[1],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -876,7 +884,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				lwd = lwd[2],
 				lty = lty[2],
 				col = col[2],
-				fill = "transparent"
+				fill = 'transparent'
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
@@ -920,11 +928,11 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") {
+		if (cat.default.pos == 'outer') {
 			cat.pos.1 <- find.cat.pos(0.4, 0.5, cat.pos[1], cat.dist[1], max.circle.size);
 			cat.pos.2 <- find.cat.pos(0.6, 0.5, cat.pos[2], cat.dist[2], max.circle.size);
 			}
-		else if (cat.default.pos == "text") {
+		else if (cat.default.pos == 'text') {
 			cat.pos.1 <- find.cat.pos(0.3, 0.5, cat.pos[1], cat.dist[1]);
 			cat.pos.2 <- find.cat.pos(0.7, 0.5, cat.pos[2], cat.dist[2]);
 			}
@@ -945,7 +953,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-		
+
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -959,11 +967,11 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-	
+
 		}
 
 	grob.list <- adjust.venn(rotate.venn.degrees(grob.list, rotation.degree, rotation.centre[1], rotation.centre[2]), ...);
-	if (ind) { grid.draw(grob.list) }
+	if (ind) { grid.draw(grob.list); }
 	return(grob.list);
-		
+
 	}
